@@ -107,7 +107,7 @@ class AdhocServiceResultsMixin:
     Mixin for adhoc:service functionality for results classes.
     """
 
-    def __init__(self, votable, url=None, session=None):
+    def __init__(self, votable, *, url=None, session=None):
         super().__init__(votable, url=url, session=session)
         self._adhocservices = list(
             resource for resource in votable.resources
@@ -263,6 +263,15 @@ class DatalinkResultsMixin(AdhocServiceResultsMixin):
         if access_url:
             return access_url
 
+    @staticmethod
+    def _guess_datalink(row, **kwargs):
+        # TODO: we should be more careful about whitespace, case
+        # and perhaps more parameters in the following comparison
+        if row._results._guess_access_format(row) == DATALINK_MIME_TYPE:
+            access_url = row._results._guess_access_url(row)
+            if access_url is not None:
+                return DatalinkResults.from_result_url(access_url, **kwargs)
+
     def _iter_datalinks_from_product_rows(self):
         """yield datalinks from self's rows if they describe datalink-valued
         products.
@@ -309,13 +318,31 @@ class DatalinkRecordMixin:
     """
 
     def getdatalink(self):
+        """
+        Retrieve the datalink information for this record.
+
+        Returns
+        -------
+        DatalinkResults
+            The datalink results for this record.
+
+        Raises
+        ------
+        DALServiceError
+            If no datalink information is found for this record.
+        """
         try:
             datalink = self._results.get_adhocservice_by_ivoid(DATALINK_IVOID)
 
             query = DatalinkQuery.from_resource(self, datalink, session=self._session)
             return query.execute()
-        except DALServiceError:
-            return DatalinkResults.from_result_url(self.getdataurl(), session=self._session)
+        except DALServiceError as error:
+            datalink = self._results._guess_datalink(self, session=self._session)
+            if datalink is not None:
+                return datalink
+            else:
+                # re-raise the original error if nothing works
+                raise DALServiceError("No datalink found for record.") from error
 
     @stream_decode_content
     def getdataset(self, timeout=None):
@@ -357,7 +384,7 @@ class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
         if hasattr(self._session, 'update_from_capabilities'):
             self._session.update_from_capabilities(self.capabilities)
 
-    def run_sync(self, id, responseformat=None, **keywords):
+    def run_sync(self, id, *, responseformat=None, **keywords):
         """
         runs sync query and returns its result
 
@@ -377,12 +404,12 @@ class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
         --------
         DatalinkResults
         """
-        return self.create_query(id, responseformat, **keywords).execute()
+        return self.create_query(id, responseformat=responseformat, **keywords).execute()
 
     # alias for service discovery
     search = run_sync
 
-    def create_query(self, id, responseformat=None, **keywords):
+    def create_query(self, id, *, responseformat=None, **keywords):
         """
         create a query object that constraints can be added to and then
         executed.  The input arguments will initialize the query with the
@@ -398,7 +425,7 @@ class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
             the output format
         """
         return DatalinkQuery(
-            self.baseurl, id, responseformat, **keywords)
+            self.baseurl, id=id, responseformat=responseformat, **keywords)
 
 
 class DatalinkQuery(DALQuery):
@@ -423,7 +450,7 @@ class DatalinkQuery(DALQuery):
     allowing the caller to take greater control of the result processing.
     """
     @classmethod
-    def from_resource(cls, rows, resource, session=None, **kwargs):
+    def from_resource(cls, rows, resource, *, session=None, **kwargs):
         """
         Creates a instance from a number of records and a Datalink Resource.
 
@@ -488,7 +515,7 @@ class DatalinkQuery(DALQuery):
             **query_params)
 
     def __init__(
-            self, baseurl, id=None, responseformat=None, session=None, **keywords):
+            self, baseurl, *, id=None, responseformat=None, session=None, **keywords):
         """
         initialize the query object with the given parameters
 
@@ -610,7 +637,7 @@ class DatalinkResults(DatalinkResultsMixin, DALResults):
         """
         return DatalinkRecord(self, index, session=self._session)
 
-    def bysemantics(self, semantics, include_narrower=True):
+    def bysemantics(self, semantics, *, include_narrower=True):
         """
         return the rows with the dataset identified by the given semantics
 
@@ -691,7 +718,7 @@ class DatalinkResults(DatalinkResultsMixin, DALResults):
                 copy_tb.resources.remove(x)
         return DatalinkResults(copy_tb, original_row=original_row)
 
-    def getdataset(self, timeout=None):
+    def getdataset(self, *, timeout=None):
         """
         return the first row with the dataset identified by semantics #this
 
@@ -741,13 +768,6 @@ class SodaRecordMixin:
         except DALServiceError:
             pass
 
-        # let it count as soda resource
-        try:
-            return self._results.get_adhocservice_by_ivoid(
-                "ivo://ivoa.net/std/datalink#links")
-        except DALServiceError:
-            pass
-
         dataformat = self.getdataformat()
         if dataformat is None:
             raise DALServiceError(
@@ -772,7 +792,7 @@ class SodaRecordMixin:
         return None
 
     def processed(
-            self, circle=None, range=None, polygon=None, band=None, **kwargs):
+            self, *, circle=None, range=None, polygon=None, band=None, **kwargs):
         """
         Returns processed dataset.
 
@@ -957,7 +977,7 @@ class SodaQuery(DatalinkQuery, AxisParamMixin):
     """
 
     def __init__(
-            self, baseurl, circle=None, range=None, polygon=None, band=None,
+            self, baseurl, *, circle=None, range=None, polygon=None, band=None,
             **kwargs):
         super().__init__(baseurl, **kwargs)
 
