@@ -367,14 +367,12 @@ class PosQueryParam(AbstractDalQueryParam):
                     self._validate_ra(m)
 
     def _validate_ra(self, ra):
-        if not isinstance(ra, Quantity):
-            ra = ra * u.deg
+        ra = Quantity(ra, u.deg)
         if ra.to(u.deg).value < 0 or ra.to(u.deg).value > 360.0:
             raise ValueError('Invalid ra: {}'.format(ra))
 
     def _validate_dec(self, dec):
-        if not isinstance(dec, Quantity):
-            dec = dec * u.deg
+        dec = Quantity(dec, u.deg)
         if dec.to(u.deg).value < -90.0 or dec.to(u.deg).value > 90.0:
             raise ValueError('Invalid dec: {}'.format(dec))
 
@@ -415,10 +413,11 @@ class IntervalQueryParam(AbstractDalQueryParam):
                 low, high))
         if self._unit:
             if not isinstance(low, Quantity):
-                low = low * self._unit
+                low = u.Quantity(low, self._unit)
             low = low.to(self._unit, equivalencies=self._equivalencies).value
+
             if not isinstance(high, Quantity):
-                high = high * self._unit
+                high = Quantity(high, self._unit)
             high = high.to(self._unit, equivalencies=self._equivalencies).value
 
             if low > high:
