@@ -20,13 +20,15 @@ other externally defined table.  In this case there is no VO defined
 standard data model.  Usually the field names are used to uniquely
 identify table columns.
 """
-__all__ = ["DALService", "DALQuery", "DALResults", "Record"]
+__all__ = ["DALService", "DALServiceError", "DALQuery", "DALQueryError",
+           "DALResults", "Record"]
 
 import os
 import shutil
 import re
 import requests
 from collections.abc import Mapping
+from io import BytesIO, StringIO
 
 import collections
 
@@ -63,7 +65,7 @@ class DALService:
            the base URL that should be used for forming queries to the service.
         session : object
            optional session to use for network requests
-        description : str, optional
+        capability_description : str, optional
            the description of the service.
         """
         self._baseurl = baseurl
@@ -211,8 +213,8 @@ class DALQuery(dict):
         except requests.RequestException as ex:
             # save for later use
             self._ex = ex
-        finally:
-            return response.raw
+
+        return response.raw
 
     def submit(self, *, post=False):
         """
@@ -694,7 +696,7 @@ class Record(Mapping):
         return len(self._mapping)
 
     def __repr__(self):
-        return repr(tuple(self.values()))
+        return repr(tuple(f'{val}' for val in self.values()))
 
     def get(self, key, default=None, decode=False):
         """
@@ -1033,15 +1035,18 @@ class Upload:
 
         # astropy table
         if isinstance(self._content, Table):
-            from io import BytesIO
+
             fileobj = BytesIO()
 
             self._content.write(output=fileobj, format="votable")
             fileobj.seek(0)
 
             return fileobj
+
+        elif isinstance(self._content, (BytesIO, StringIO)):
+            return self._content
+
         elif isinstance(self._content, DALResults):
-            from io import BytesIO
             fileobj = BytesIO()
 
             table = self._content.to_table()
@@ -1050,11 +1055,9 @@ class Upload:
 
             return fileobj
 
-        fileobj = self._content
-        try:
-            fileobj = open(self._content)
-        finally:
-            return fileobj
+        fileobj = open(self._content)
+
+        return fileobj
 
     def uri(self):
         """
