@@ -1,6 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from astropy.utils.collections import HomogeneousList
-from astropy.utils.misc import indent
+from textwrap import indent
 
 from astropy.io.votable.exceptions import vo_raise, warn_or_raise
 
@@ -17,6 +17,9 @@ __all__ = [
     "TimeLimits", "DataLimits", "DataLimit"]
 
 
+INDENT = 4 * " "
+
+
 ######################################################################
 # ELEMENT CLASSES
 class DataModelType(ContentMixin, Element):
@@ -37,7 +40,7 @@ class DataModelType(ContentMixin, Element):
         Prints out a human readable description
         """
         print("Datamodel {}".format(self.content))
-        print(indent(self.ivo_id))
+        print(indent(self.ivo_id, INDENT))
         print()
 
     @xmlattribute(name='ivo-id')
@@ -71,8 +74,8 @@ class OutputFormat(Element):
         print('Output format {}'.format(self.mime))
 
         if self.aliases:
-            print(indent('Also available as {}'.format(
-                ', '.join(self.aliases))))
+            print(indent('Also available as {}'.format(', '.join(self.aliases)),
+                         INDENT))
 
         print()
 
@@ -104,7 +107,7 @@ class UploadMethod(Element):
         Prints out a human readable description
         """
         print("Upload method supported")
-        print(indent(self.ivo_id))
+        print(indent(self.ivo_id, INDENT))
         print()
 
     @xmlattribute(name='ivo-id')
@@ -238,13 +241,13 @@ class Language(Element):
         print("Language {}".format(self.name))
 
         for languagefeaturelist in self.languagefeaturelists:
-            print(indent(languagefeaturelist.type))
+            print(indent(languagefeaturelist.type, INDENT))
 
             for feature in languagefeaturelist:
-                print(indent(feature.form, shift=2))
+                print(indent(feature.form, 2 * INDENT))
 
                 if feature.description:
-                    print(indent(feature.description, shift=3))
+                    print(indent(feature.description, 3 * INDENT))
 
                 print()
 
@@ -467,34 +470,34 @@ class TableAccess(TAPCapRestriction):
 
         if self.retentionperiod:
             print("Time a job is kept (in seconds)")
-            print(indent("Default {}".format(self.retentionperiod.default)))
+            print(indent("Default {}".format(self.retentionperiod.default), INDENT))
             if self.retentionperiod.hard:
-                print(indent("Maximum {}".format(self.retentionperiod.hard)))
+                print(indent("Maximum {}".format(self.retentionperiod.hard), INDENT))
             print()
 
         if self.executionduration:
             print("Maximal run time of a job")
-            print(indent("Default {}".format(self.executionduration.default)))
+            print(indent("Default {}".format(self.executionduration.default), INDENT))
             if self.executionduration.hard:
-                print(indent("Maximum {}".format(self.executionduration.hard)))
+                print(indent("Maximum {}".format(self.executionduration.hard), INDENT))
             print()
 
         if self.outputlimit:
             print("Maximum size of resultsets")
             print(indent("Default {} {}".format(
                 self.outputlimit.default.content,
-                self.outputlimit.default.unit))
+                self.outputlimit.default.unit), INDENT)
             )
             if self.outputlimit.hard:
                 print(indent("Maximum {} {}".format(
-                    self.outputlimit.hard.content, self.outputlimit.hard.unit))
+                    self.outputlimit.hard.content, self.outputlimit.hard.unit), INDENT)
                 )
             print()
 
         if self.uploadlimit:
             print("Maximal size of uploads")
             print(indent("Maximum {} {}".format(
-                self.uploadlimit.hard.content, self.uploadlimit.hard.unit)))
+                self.uploadlimit.hard.content, self.uploadlimit.hard.unit), INDENT))
             print()
 
     def get_adql(self):
